==> web_exploit_detector-1.0.0.tgz: package/rules/php/index.js <==
module.exports = [
  {
    id: 'P64:php:phpinfo',
    name: 'Matches any PHP script containing a call to phpinfo()',
    description: 'phpinfo() is a useful way of showing the current server configuration in a human-readable format, however is exposes some sensitive information to potential attackers. This rule detects PHP scripts that contain this function call as this could be the indication of a script created maliciously.',
    urls: null,
    deprecated: false,
    tags: ['suspicion', 'php', 'phpinfo'],
    tests: {
      path: (f) => (
        !!(
          f.match(/\.php$/i) &&

          // Some WordPress internal files include safe calls to phpinfo(), so exclude them
          !f.match(/wp-includes\/functions\.php$/i) &&
          !f.match(/wp-admin\/includes\/class-wp-filesystem-ssh2\.php$/i) &&

          // Exclude WordPress wordfence plug-in files
          !f.match(/wp-content\/plugins\/wordfence\/lib\/menu_tools_diagnostic\.php$/i) &&
          !f.match(/wp-content\/plugins\/wordfence\/lib\/sysinfo\.php$/i) &&
          !f.match(/wp-content\/plugins\/wordfence\/lib\/wordfenceClass\.php$/i) &&

          // Exclude WordPress updraftplus plug-in files
          !f.match(/wp-content\/plugins\/updraftplus\/central\/modules\/core\.php$/i) &&
          !f.match(/wp-content\/plugins\/updraftplus\/includes\/class-wpadmin-commands\.php$/i) &&
          !f.match(/wp-content\/plugins\/updraftplus\/admin\.php$/i) &&

          // Exclude WordPress w3-total-cache plug-in files
          !f.match(/wp-content\/plugins\/w3-total-cache\/Support_AdminActions\.php$/i) &&
          !f.match(/wp-content\/plugins\/w3-total-cache\/inc\/options\/install\.php$/i) &&

          // Exclude phpseclib files
          !f.match(/phpseclib\/Crypt\/RSA\.php$/i) &&
          !f.match(/phpseclib\/Math\/BigInteger\.php$/i) &&

          // Exlude Symfony "process" files
          !f.match(/symfony\/process\/Process\.php$/i) &&
          !f.match(/symfony\/process\/Tests\/ProcessTest\.php$/i)
        )
      ),
      content: (content) => {
        return !!(content.match(/phpinfo\(/) && !content.match(/\/\/\s+phpinfo\(/));
      },
    }
  },

  {
    id: 'P64:php:mod_infoslider_spam_mailer',
    name: 'Matches a PHP script (perhaps named mod_infoslider.php) which allows sending of bulk spam',
    description: 'This rules matches a malicious script which enables an attacker to use a server to send bulk spam e-mail.',
    urls: null,
    deprecated: false,
    tags: ['php', 'general', 'spam', 'mailer', 'mail', 'mod_infoslider'],
    tests: {
      path: /\.php$/i,
      content: (content, f) => {
        if (f.match(/mod_infoslider\.php$/i))
          return true;
        return !!(
          content.match(/[\s+.]+mail\s*\(/) &&
          (
            content.match(/\$mailNRA/i) ||
            content.match(/\$mailNRB/i) ||
            content.match(/\$mailRNA/i) ||
            content.match(/\$mailRNB/i) ||
            content.match(/\$MailList/)
          )
        );
      },
    },
  },
];

==> web_exploit_detector-1.1.2.tgz: package/rules/php/index.js <==
module.exports = [
  {
    id: 'P64:php:phpinfo',
    name: 'Matches any PHP script containing a call to phpinfo()',
    description: 'phpinfo() is a useful way of showing the current server configuration in a human-readable format, however is exposes some sensitive information to potential attackers. This rule detects PHP scripts that contain this function call as this could be the indication of a script created maliciously.',
    urls: null,
    deprecated: false,
    tags: ['suspicion', 'php', 'phpinfo'],
    tests: {
      path: (f) => (
        !!(
          f.match(/\.php$/i) &&

          // Some WordPress internal files include safe calls to phpinfo(), so exclude them
          !f.match(/wp-includes\/functions\.php$/i) &&
          !f.match(/wp-admin\/includes\/class-wp-filesystem-ssh2\.php$/i) &&

          // Exclude WordPress wordfence plug-in files
          !f.match(/wp-content\/plugins\/wordfence\/lib\/menu_tools_diagnostic\.php$/i) &&
          !f.match(/wp-content\/plugins\/wordfence\/lib\/sysinfo\.php$/i) &&
          !f.match(/wp-content\/plugins\/wordfence\/lib\/wordfenceClass\.php$/i) &&

          // Exclude WordPress updraftplus plug-in files
          !f.match(/wp-content\/plugins\/updraftplus\/central\/modules\/core\.php$/i) &&
          !f.match(/wp-content\/plugins\/updraftplus\/includes\/class-wpadmin-commands\.php$/i) &&
          !f.match(/wp-content\/plugins\/updraftplus\/admin\.php$/i) &&

          // Exclude WordPress w3-total-cache plug-in files
          !f.match(/wp-content\/plugins\/w3-total-cache\/Support_AdminActions\.php$/i) &&
          !f.match(/wp-content\/plugins\/w3-total-cache\/inc\/options\/install\.php$/i) &&

          // Exclude phpseclib files
          !f.match(/phpseclib\/Crypt\/RSA\.php$/i) &&
          !f.match(/phpseclib\/Math\/BigInteger\.php$/i) &&

          // Exlude Symfony "process" files
          !f.match(/symfony\/process\/Process\.php$/i) &&
          !f.match(/symfony\/process\/Tests\/ProcessTest\.php$/i)
        )
      ),
      content: (content) => {
        return !!(content.match(/phpinfo\s*\(/) && !content.match(/\/\/\s*phpinfo\s*\(/));
      },
    }
  },

  {
    id: 'P64:php:mod_infoslider_spam_mailer',
    name: 'Matches a PHP script (perhaps named mod_infoslider.php) which allows sending of bulk spam',
    description: 'This rules matches a malicious script which enables an attacker to use a server to send bulk spam e-mail.',
    urls: null,
    deprecated: false,
    tags: ['php', 'general', 'spam', 'mailer', 'mail', 'mod_infoslider'],
    tests: {
      path: /\.php$/i,
      content: (content, f) => {
        if (f.match(/mod_infoslider\.php$/i))
          return true;
        return !!(
          content.match(/[\s+.]*mail\s*\(/) &&
          (
            content.match(/\$mailNRA/i) ||
            content.match(/\$mailNRB/i) ||
            content.match(/\$mailRNA/i) ||
            content.match(/\$mailRNB/i) ||
            content.match(/\$MailList/)
          )
        );
      },
    },
  },
];
